@@ -104,35 +104,17 @@ in this Software without prior written authorization from The Open Group.
  * STORE macros
  */
 
-#ifndef WORD64
-
 #define STORE_CARD32(_pBuf, _val) \
 { \
     *((CARD32 *) _pBuf) = _val; \
     _pBuf += 4; \
 }
 
-#else /* WORD64 */
-
-#define STORE_CARD32(_pBuf, _val) \
-{ \
-    struct { \
-        int value   :32; \
-    } _d; \
-    _d.value = _val; \
-    memcpy (_pBuf, &_d, 4); \
-    _pBuf += 4; \
-}
-
-#endif /* WORD64 */
-
 
 /*
  * EXTRACT macros
  */
 
-#ifndef WORD64
-
 #define EXTRACT_CARD16(_pBuf, _swap, _val) \
 { \
     _val = *((CARD16 *) _pBuf); \
@@ -149,34 +131,6 @@ in this Software without prior written authorization from The Open Group.
         _val = lswapl (_val); \
 }
 
-#else /* WORD64 */
-
-#define EXTRACT_CARD16(_pBuf, _swap, _val) \
-{ \
-    _val = *(_pBuf + 0) & 0xff; 	/* 0xff incase _pBuf is signed */ \
-    _val <<= 8; \
-    _val |= *(_pBuf + 1) & 0xff;\
-    _pBuf += 2; \
-    if (_swap) \
-        _val = lswaps (_val); \
-}
-
-#define EXTRACT_CARD32(_pBuf, _swap, _val) \
-{ \
-    _val = *(_pBuf + 0) & 0xff; 	/* 0xff incase _pBuf is signed */ \
-    _val <<= 8; \
-    _val |= *(_pBuf + 1) & 0xff;\
-    _val <<= 8; \
-    _val |= *(_pBuf + 2) & 0xff;\
-    _val <<= 8; \
-    _val |= *(_pBuf + 3) & 0xff;\
-    _pBuf += 4; \
-    if (_swap) \
-        _val = lswapl (_val); \
-}
-
-#endif /* WORD64 */
-
 
 /*
  * Compute the number of bytes for a LISTofPROPERTY representation
@@ -203,7 +157,7 @@ in this Software without prior written authorization from The Open Group.
 
 #define STORE_ARRAY8(_pBuf, _len, _array8) \
 { \
-    STORE_CARD32 (_pBuf, _len); \
+    STORE_CARD32 (_pBuf, (CARD32) _len); \
     if (_len) \
         memcpy (_pBuf, _array8, _len); \
     _pBuf += _len + PAD64 (4 + _len); \
@@ -286,7 +240,7 @@ in this Software without prior written authorization from The Open Group.
 
 #define SKIP_LISTOF_PROPERTY(_pBuf, _swap) \
 { \
-    int _i, _j; \
+    CARD32 _i, _j; \
     CARD32 _count; \
     EXTRACT_CARD32 (_pBuf, _swap, _count); \
     _pBuf += 4; \
